%global desc These provide several pieces of "middleware" (or filters) that can be nested\
to build web applications.  Each piece of middleware uses the WSGI (PEP 333)\
interface, and should be compatible with other middleware based on those\
interfaces.
%global sum Tools for using a Web Server Gateway Interface stack

Name:           python-paste
Version:        2.0.3
Release:        9%{?dist}
BuildArch:      noarch

# Most of the code is MIT
# paste/exceptions/collector.py is ZPLv2.0
# paste/evalexception/media/MochiKit.packed.js AFL (2.1) or MIT
# paste/lint.py MIT or Apache v2
# PySourceColor.py, Python
License:        MIT and ZPLv2.0 and Python and (AFL or MIT) and (MIT or ASL 2.0)
Summary:        %sum
URL:            https://bitbucket.org/ianb/paste/
Source0:        https://files.pythonhosted.org/packages/source/P/Paste/Paste-%{version}.tar.gz

# https://bitbucket.org/ianb/paste/pull-requests/41
Patch0:         python37.patch

BuildRequires:  python2-pyOpenSSL
BuildRequires:  python2-tempita
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
BuildRequires:  python2-six >= 1.4.0
BuildRequires:  python2-nose >= 0.11
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-pyOpenSSL
BuildRequires:  python3-setuptools
BuildRequires:  python3-six >= 1.4.0
BuildRequires:  python3-tempita


%description
%desc


%package -n python2-paste
Summary:  %sum

%{?python_provide:%python_provide python2-paste}

Requires: python2-pyOpenSSL
Requires: python2-tempita
Requires: python2-setuptools
Requires: python2-six >= 1.4.0


%description -n python2-paste
%{desc}


%package -n python3-paste
Summary:        Tools for using a Web Server Gateway Interface stack

%{?python_provide:%python_provide python3-paste}

Requires: python3-pyOpenSSL
Requires: python3-setuptools
Requires: python3-six
Requires: python3-tempita


%description -n python3-paste
%{desc}


%prep
%autosetup -n Paste-%{version} -p1

# Paste-2.0.3 seems to have a few .py.orig files that don't appear in upstream scm. Let's drop them.
find . -name "*.orig" -delete

# Strip #! lines that make these seem like scripts
%{__sed} -i -e '/^#!.*/,1 d' paste/util/scgiserver.py paste/debug/doctest_webapp.py

# clean docs directory
pushd docs
rm StyleGuide.txt
popd

rm -rf %{py3dir}
cp -a . %{py3dir}


%build
%{__python2} setup.py build

pushd %{py3dir}
%{__python3} setup.py build
popd


%install
%{__python2} setup.py install --skip-build --root %{buildroot}

pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
popd


%check
export PYTHONPATH=$(pwd)
# We don't have access to the wider internet in the buildsystem
nosetests-%{python2_version} -e '.*test_paste_website'

pushd %{py3dir}
export PYTHONPATH=$(pwd)
# We don't have access to the wider internet in the buildsystem
nosetests-%{python3_version} -e '.*test_paste_website'
popd


%files -n python2-paste
%license docs/license.txt
%doc docs/*
%{python2_sitelib}/paste
%{python2_sitelib}/Paste-%{version}-py%{python2_version}.egg-info
%{python2_sitelib}/Paste-%{version}-py%{python2_version}-nspkg.pth


%files -n python3-paste
%license docs/license.txt
%doc docs/*
%{python3_sitelib}/paste
%{python3_sitelib}/Paste-%{version}-py%{python3_version}.egg-info
%{python3_sitelib}/Paste-%{version}-py%{python3_version}-nspkg.pth


%changelog
* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.3-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 18 2018 Miro Hrončok <mhroncok@redhat.com> - 2.0.3-7
- Rebuilt for Python 3.7

* Fri Jun 08 2018 Miro Hrončok <mhroncok@redhat.com> - 2.0.3-6
- Fix build on Python 3.7 (#1583818)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 26 2018 Iryna Shcherbina <ishcherb@redhat.com> - 2.0.3-4
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan 05 2017 Randy Barlow <bowlofeggs@fedoraproject.org> - 2.0.3-1
- Update to 2.0.3 (#1316101).
- Use the python_provides macro and rename python-paste to python2-paste.
- Drop conditionals on building python3-paste.
- Use the license macro.
- Dropped py3 fixes patch, since it is included in the upstream 2.0.3 release.
- Update URL, since old one doesn't load anymore.
- Reorganize spec file.
- Don't rm the buildroot before install.
- Drop some .orig files.
- Add BuildRequires on six.
- Drop unneeded clean section.
- Drop unneeded defattr in the files sections.
- Don't use * to select files in the Python sitelib, list them explicitly.

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.0.2-5
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue May 31 2016 Nils Philippsen <nils@redhat.com>
- fix source URL

* Tue Mar 08 2016 Nils Philippsen <nils@redhat.com> - 2.0.2-3
- add python3-pyOpenSSL dependencies

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Nov 13 2015 Nils Philippsen <nils@redhat.com> - 2.0.2-1
- various Python 3 fixes
- don't attempt to access the Internet in tests

* Mon Aug 17 2015 Nils Philippsen <nils@redhat.com> - 2.0.2-1
- version 2.0.2
- update license info
- remove obsolete unbundle-stdlib, 27-lambda, sigest-snap, string-letters
  patches
- remove private tempita implementation as we require it anyway
- reenable python 3 support
- fix bogus changelog date

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5.1-12.20111221hg1498
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 17 2014 Luke Macken <lmacken@redhat.com> - 1.7.5.1-11.20111221hg1498
- Patch the test suite to get it passing on rawhide (#1106785)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5.1-10.20111221hg1498
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5.1-9.20111221hg1498
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5.1-8.20111221hg1498
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5.1-7.20111221hg1498
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jan 23 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.5.1-6.20111221hg1498
- Disable python3 subpackage as paste is not python3 compatible at this time

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5.1-5.20111221hg1498
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Dec 21 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.5.1-4.20111221hg1498
- Tarball is missing files, use a snapshot to get those files and also pick up
  several bug fixes (one related to serving CGI scripts, another for http
  Continue requests, and a third regarding digest authentication and internet
  explorer)

* Tue Dec 20 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.5.1-3
- Ugh.  Enable unittests and make a note that the python3 module is totally
  non-functional.  Open a bug for that for the actual package maintainers to
  make a decision on.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Sep 22 2010 Luke Macken <lmacken@redhat.com> - 1.7.5.1-1
- 1.7.5.1 upstream release

* Wed Sep 15 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.5-1
- New upstream bugfix

* Mon Aug 23 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.4-8
- Rebuild for python3-3.2

* Mon Aug  2 2010 Kyle VanderBeek <kylev@kylev.com> - 1.7.4-7
- Add python3 version.
- Fix python 2.7/3 incompatible lambda syntax.
- Unbundle stdlib (2.4+) subprocess module (removed because it isn't even 3.x legal).

* Fri Jul 30 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.4-6
- Include another function from tempita that is used by paste-script.

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 1.7.4-5
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Jul 9 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.4-4
- Actually apply the patches :-(

* Fri Jul 2 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.4-3
- Require pyOpenSSL so that we get SSL capabilities

* Thu Jul 1 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.7.4-2
- Unbundle tempita and don't rely on utils.string24

* Thu Jun 24 2010 Luke Macken <lmacken@redhat.com> - 1.7.4-1
- 1.7.4 security release

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun 22 2009 Kyle VanderBeek <kylev@kylev.com> - 1.7.2-3
- Package formerly ghost'ed .pyo files
- Update to current python package methods

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Jan 06 2009 Luke Macken <lmacken@redhat.com> - 1.7.2-1
- Update to 1.7.2

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.7.1-2
- Rebuild for Python 2.6

* Sat Jun 14 2008 Luke Macken <lmacken@redhat.com> - 1.7.1-1
- Update to Paste 1.7.1

* Thu Feb 28 2008 Luke Macken <lmacken@redhat.com> - 1.6-1
- Update to 1.6

* Wed Oct  3 2007 Luke Macken <lmacken@redhat.com> - 1.4.2-1
- 1.4.2

* Sun Sep  2 2007 Luke Macken <lmacken@redhat.com> - 1.4-2
- Update for python-setuptools changes in rawhide

* Sun Jul  8 2007 Luke Macken <lmacken@redhat.com> - 1.4-1
- 1.4

* Sat Mar  3 2007 Luke Macken <lmacken@redhat.com> - 1.2.1-1
- 1.2.1

* Sat Dec  9 2006 Luke Macken <lmacken@redhat.com> - 1.0-2
- Add python-devel to BuildRequires
- 1.0

* Sun Sep 17 2006 Luke Macken <lmacken@redhat.com> - 0.9.8.1-1
- 0.9.8.1

* Sun Sep  3 2006 Luke Macken <lmacken@redhat.com> - 0.9.3-5
- Rebuild for FC6

* Wed Jul 19 2006 Luke Macken <lmacken@redhat.com> - 0.9.3-4
- Use a smarter shebang removal expression

* Wed Jul 19 2006 Luke Macken <lmacken@redhat.com> - 0.9.3-3
- Fix doc inclusion

* Sat Jul 15 2006 Luke Macken <lmacken@redhat.com> - 0.9.3-2
- Clean up docs directory
- Remove shebang from from non-executable scripts
- Use consistent build root variables

* Mon Jul 10 2006 Luke Macken <lmacken@redhat.com> - 0.9.3-1
- Initial package
